@@ -4,7 +4,7 @@
 import binascii
 import re
 
-from cli_helpers.compat import binary_type, text_type
+from cli_helpers.compat import binary_type, text_type, Terminal256Formatter, StringIO
 
 
 def bytes_to_string(b):
@@ -55,7 +55,7 @@ def unique_items(seq):
     return [x for x in seq if not (x in seen or seen.add(x))]
 
 
-_ansi_re = re.compile('\033\[((?:\d|;)*)([a-zA-Z])')
+_ansi_re = re.compile('\033\\[((?:\\d|;)*)([a-zA-Z])')
 
 
 def strip_ansi(value):
@@ -68,3 +68,11 @@ def replace(s, replace):
     for r in replace:
         s = s.replace(*r)
     return s
+
+
+def style_field(token, field, style):
+    """Get the styled text for a *field* using *token* type."""
+    formatter = Terminal256Formatter(style=style)
+    s = StringIO()
+    formatter.format(((token, field),), s)
+    return s.getvalue()
